@@ -32,6 +32,7 @@
 import dataclasses as dtcl
 import importlib as imlb
 import json
+import pathlib as pthl
 import sys as sstm
 from array import array as py_array_t
 from datetime import date as date_t
@@ -41,7 +42,7 @@ from datetime import timedelta as time_delta_t
 from datetime import timezone as time_zone_t
 from enum import Enum as enum_t
 from io import BytesIO as io_bytes_t
-from pathlib import Path as path_t
+from pathlib import PurePath as path_t
 from typing import Any, Callable, Dict, GenericAlias, Optional, Tuple, Union
 from uuid import UUID as uuid_t
 
@@ -57,10 +58,17 @@ try:
     import numpy as nmpy
 except ModuleNotFoundError:
     nmpy = None
+try:
+    import pandas as pnds
+except ModuleNotFoundError:
+    pnds = None
+try:
+    import scipy.sparse as sprs
+except ModuleNotFoundError:
+    sprs = None
 if nmpy is None:
     blsc = None
     pcst = None
-    sprs = None
 else:
     try:
         import blosc as blsc
@@ -70,10 +78,6 @@ else:
         import pca_b_stream as pcst
     except ModuleNotFoundError:
         pcst = None
-    try:
-        import scipy.sparse as sprs
-    except ModuleNotFoundError:
-        sprs = None
 
 
 builders_h = Dict[str, Callable[[Any], Any]]
@@ -94,6 +98,11 @@ if nmpy is None:
     array_t = bytes
 else:
     array_t = nmpy.ndarray
+if pnds is None:
+    series_t = data_frame_t = bytes
+else:
+    series_t = pnds.Series
+    data_frame_t = pnds.DataFrame
 if sprs is None:
     _SPARSE_ARRAY_CLASSES = bytes
 else:
@@ -287,7 +296,7 @@ def _JsonableVersionOf(
             for _key, _vle in instance.items()
         }
     elif issubclass(instance_type, path_t):
-        json_type, jsonable = "pathlib_Path", str(instance)
+        json_type, jsonable = f"pathlib_{instance_type.__name__}", str(instance)
     elif instance_type is io_bytes_t:
         # Buffer is assumed to be open (i.e. no instance.closed check)
         json_type = "io_BytesIO"
@@ -314,6 +323,9 @@ def _JsonableVersionOf(
         json_type, jsonable = f"scipy_{instance_type.__name__}", _AsMostConcise(
             instance.toarray()
         )
+    elif instance_type in (data_frame_t, series_t):
+        pandas_type = "series" if instance_type is series_t else "frame"
+        json_type, jsonable = f"pandas_{pandas_type}", instance.to_json()
     elif instance_type in _NX_GRAPH_CLASSES:
         edges = grph.to_dict_of_dicts(instance)
         # /!\ Node attributes are added to the edges dictionary! This must be taken into account when deJSONing. Note
@@ -473,8 +485,10 @@ def _ObjectFromUnJSONed(
             ): _ObjectFromUnJSONed(_vle, builders=builders)
             for _key, _vle in instance.items()
         }
-    elif json_type == "pathlib_Path":
-        output = path_t(instance)
+    elif json_type.startswith("pathlib_"):
+        path_type = json_type[8:]
+        path_type_t = getattr(pthl, path_type)
+        output = path_type_t(instance)
     elif json_type == "io_BytesIO":
         output = io_bytes_t(instance.encode(encoding="iso-8859-1"))
     elif json_type == "uuid_UUID":
@@ -491,6 +505,9 @@ def _ObjectFromUnJSONed(
         sparse_type = json_type[6:]
         sparse_type_t = getattr(sprs, sparse_type)
         output = sparse_type_t(_AsArray(*instance))
+    elif json_type.startswith("pandas_"):
+        pandas_type = json_type[7:]
+        output = pnds.read_json(path_or_buf=instance, typ=pandas_type)
     elif json_type.startswith("networkx_"):
         graph_type = json_type[9:]
         graph_type_t = getattr(grph, graph_type)
